<?php
namespace core\sms;

use core\exception\NoticeException;
use Exception;


class Smsbao extends BaseSms
{

    protected $username = '';
    protected $secret_key = '';
    protected $sign = '';
    protected $smsapi = "http://api.smsbao.com/sms";
    protected $statusStr = array(
        "0" => "短信发送成功",
        "-1" => "参数不全",
        "-2" => "服务器空间不支持,请确认支持curl或者fsocket，联系您的空间商解决或者更换空间！",
        "30" => "密码错误",
        "40" => "账号不存在",
        "41" => "余额不足",
        "42" => "帐户已过期",
        "43" => "IP地址限制",
        "50" => "内容含有敏感词"
        );

    /**
     * @param array $config
     * @return void
     */
    protected function initialize(array $config = [])
    {
        parent::initialize($config);
        $this->username = $config[ 'username' ] ?? '';
        $this->secret_key = $config[ 'secret_key' ] ?? '';
        $this->sign = $config[ 'sign' ] ?? '';
    }


    /**
     * 发送短信
     * @param string $mobile
     * @param string $template_id
     * @param array $data
     * @return array
     */
    public function send(string $mobile, string $template_id, array $data = [])
    {
        try {
            $search = array_map(function($key) {
                return '{' . $key . '}'; // 将键转换为 {key} 形式
            }, array_keys($data));
            
            $replace = array_values($data); // 替换内容为数组的值
            // 执行替换
            $content = str_replace($search, $replace, $template_id);
            $url = $this->smsapi.'?u='.$this->username.'&p='.$this->secret_key.'&m='.$mobile.'&c=【'.$this->sign.'】'.$content;
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_TIMEOUT, 30 );
            $response = curl_exec($ch);
            curl_close($ch);
            throw new NoticeException($this->statusStr[$response]);
        } catch (Exception $e) {
            throw new NoticeException($e->getMessage());
        }
    }

    public function modify(string $sign, string $mobile, string $code)
    {
    }

    public function template(int $page = 0, int $limit = 10, int $type = 1)
    {
    }

    public function apply(string $title, string $content, int $type)
    {
    }

    public function localTemplate(int $type, int $page, int $limit)
    {
    }

    public function record($id)
    {
    }
}